==> Acme-PERLANCAR-Dummy-0.007.tar.gz: Acme-PERLANCAR-Dummy-0.007/lib/Acme/PERLANCAR/Dummy/ModuleFeatures/Module1.pm <==
package Acme::PERLANCAR::Dummy::ModuleFeatures::Module1;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-03-26'; # DATE
our $DIST = 'Acme-PERLANCAR-Dummy'; # DIST
our $VERSION = '0.007'; # VERSION

use strict;
use warnings;

1;
# ABSTRACT: A module

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::PERLANCAR::Dummy::ModuleFeatures::Module1 - A module

=head1 VERSION

This document describes version 0.007 of Acme::PERLANCAR::Dummy::ModuleFeatures::Module1 (from Perl distribution Acme-PERLANCAR-Dummy), released on 2021-03-26.

=head1 DESCRIPTION

This is a dummy module for testing.

=head1 DECLARED FEATURES

Features declared by this module (actually declared in L<Acme::PERLANCAR::Dummy::ModuleFeatures::Module1::_ModuleFeatures>):

=head2 From feature set Dummy

Features from feature set L<Dummy|Module::Features::Dummy> declared by this module:

=over

=item * feature1

Value: yes.

=item * feature2

Value: yes.

=item * feature3

Value: "b".

=back

For more details on module features, see L<Module::Features>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-PERLANCAR-Dummy>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-PERLANCAR-Dummy>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Acme-PERLANCAR-Dummy/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Acme-PERLANCAR-Dummy-0.008.tar.gz: Acme-PERLANCAR-Dummy-0.008/lib/Acme/PERLANCAR/Dummy/ModuleFeatures/Module1.pm <==
package Acme::PERLANCAR::Dummy::ModuleFeatures::Module1;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-07-18'; # DATE
our $DIST = 'Acme-PERLANCAR-Dummy'; # DIST
our $VERSION = '0.008'; # VERSION

use strict;
use warnings;

1;
# ABSTRACT: A module

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::PERLANCAR::Dummy::ModuleFeatures::Module1 - A module

=head1 VERSION

This document describes version 0.008 of Acme::PERLANCAR::Dummy::ModuleFeatures::Module1 (from Perl distribution Acme-PERLANCAR-Dummy), released on 2021-07-18.

=head1 DESCRIPTION

This is a dummy module for testing.

=head1 DECLARED FEATURES

Features declared by this module (actually declared in L<Acme::PERLANCAR::Dummy::ModuleFeatures::Module1::_ModuleFeatures>):

=head2 From feature set Dummy

Features from feature set L<Dummy|Module::Features::Dummy> declared by this module:

=over

=item * feature1

Value: no.

=item * feature2

Value: no.

=item * feature3

Value: yes.

=back

For more details on module features, see L<Module::Features>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-PERLANCAR-Dummy>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-PERLANCAR-Dummy>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-PERLANCAR-Dummy>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
